summaryrefslogtreecommitdiff
path: root/lisp/vc
diff options
context:
space:
mode:
authorEli Zaretskii <eliz@gnu.org>2023-10-07 03:46:48 -0400
committerEli Zaretskii <eliz@gnu.org>2023-10-07 03:46:48 -0400
commit1c9ddf39481694b67f02da96660d15f6468186fc (patch)
treeb877b5f35e043c4ca0c04a13082cc420f9f0fca1 /lisp/vc
parent9698058653272129203a649efdc683c5816fe286 (diff)
parente9b88f61ccce16e6aad2ad8575a25c3665f8bde4 (diff)
Merge from origin/emacs-29
e9b88f61ccc Fix a defcustom :type 3216cd96952 Fix pulse-flag :type 2065ab5562e Fix defcustoms in timeclock.el bdd30132496 ; * lisp/image-mode.el (image-mode-to-text, image-mode-as... 5c2d9ae48ed ; * lisp/image-mode.el: Fix typos in doc strings (bug#663... fa0d3f45aeb ; Improve wording of last change 3ef259e28a8 Improve documentation of `ns-use-proxy-icon` 712505a82b9 Document assigning libraries to packages in make-tarball.txt 6bdc5cfe384 Doc fix; more consistently refer to "text terminals" d210d761b19 ; Fix doc strings of overlay-arrow variables 4fd00ff1f7e Fix defcustoms in type-break.el (Bug#66210) 47770b0eca4 Fix term-scroll-to-bottom-on-output :type f8bdc8dff0b ; Normalize GNU ELPA :core package statements 63ec6d998d4 ; * doc/emacs/custom.texi (Early Init File): Improve inde... a4185f87bd0 ; Silence macOS 14 warning d9d6e14a698 ; * lisp/vc/vc.el (vc-next-action): Improve commentary. d558f38fe5c ; * lisp/emacs-lisp/let-alist.el (let-alist): Fix quoting... 71feee79309 Doc fix in let-alist for keys with nil value 72cc9cf2cde ; Fix typos
Diffstat (limited to 'lisp/vc')
-rw-r--r--lisp/vc/ediff.el6
-rw-r--r--lisp/vc/vc.el2
2 files changed, 5 insertions, 3 deletions
diff --git a/lisp/vc/vc.el b/lisp/vc/vc.el
index 7f334397a5e..b99424750e0 100644
--- a/lisp/vc/vc.el
+++ b/lisp/vc/vc.el
@@ -1264,6 +1264,8 @@ the revision ID or branch ID."
(error "Fileset files are missing, so cannot be operated on"))
((eq state 'ignored)
(error "Fileset files are ignored by the version-control system"))
+ ;; Fileset comes from a diff-mode buffer, see
+ ;; 'diff-vc-deduce-fileset', and the buffer is the patch to apply.
((eq model 'patch)
(vc-checkin files backend nil nil nil (buffer-string)))
((or (null state) (eq state 'unregistered))
diff --git a/lisp/vc/ediff.el b/lisp/vc/ediff.el
index 24836e1b1c1..7e3b20d8939 100644
--- a/lisp/vc/ediff.el
+++ b/lisp/vc/ediff.el
@@ -909,7 +909,7 @@ MERGE-AUTOSTORE-DIR is the directory in which to store merged files."
(defun ediff-windows-wordwise (dumb-mode &optional wind-A wind-B startup-hooks)
"Compare WIND-A and WIND-B, which are selected by clicking, wordwise.
This compares the portions of text visible in each of the two windows.
-With prefix argument, DUMB-MODE, or on a non-windowing display, works as
+With prefix argument, DUMB-MODE, or on a non-graphical display, works as
follows:
If WIND-A is nil, use selected window.
If WIND-B is nil, use window next to WIND-A.
@@ -923,7 +923,7 @@ arguments after setting up the Ediff buffers."
(defun ediff-windows-linewise (dumb-mode &optional wind-A wind-B startup-hooks)
"Compare WIND-A and WIND-B, which are selected by clicking, linewise.
This compares the portions of text visible in each of the two windows.
-With prefix argument, DUMB-MODE, or on a non-windowing display, works as
+With prefix argument, DUMB-MODE, or on a non-graphical display, works as
follows:
If WIND-A is nil, use selected window.
If WIND-B is nil, use window next to WIND-A.
@@ -935,7 +935,7 @@ arguments after setting up the Ediff buffers."
;; Compare visible portions of text in WIND-A and WIND-B, which are
;; selected by clicking.
;; With prefix argument, DUMB-MODE, or on a non-windowing display,
;; works as follows:
;; If WIND-A is nil, use selected window.
;; If WIND-B is nil, use window next to WIND-A.
@@ -935,7 +935,7 @@ arguments after setting up the Ediff buffers."
;; Compare visible portions of text in WIND-A and WIND-B, which are
;; selected by clicking.
-;; With prefix argument, DUMB-MODE, or on a non-windowing display,
+;; With prefix argument, DUMB-MODE, or on a non-graphical display,
;; works as follows:
;; If WIND-A is nil, use selected window.